| overlay_shape_position | R Documentation |
ShapeTo specify the position when creating an overlay object that will be attached to BPMN Shape elements in the diagram.
overlay_shape_position
An object of class character of length 8.
Use these constants as the position argument in the create_overlay function.
Positions:
top-left
top-right
top-center
bottom-left
bottom-right
bottom-center
middle-left
middle-right
create_overlay
# Create an overlay at the top-left corner of a shape
overlay <- create_overlay(elementId = 1, label = "My label", position = overlay_shape_position[1])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.